=========
colortest
=========

|PyPI| |Pythons| |CI| |Codecov|

.. |PyPI| image:: https://img.shields.io/pypi/v/colortest.svg
  :alt: PyPI version
  :target: https://pypi.org/project/colortest/

.. |Pythons| image:: https://img.shields.io/pypi/pyversions/colortest.svg
  :alt: Supported Python versions
  :target: https://pypi.org/project/colortest/

.. |CI| image:: https://github.com/Julian/colortest/workflows/CI/badge.svg
  :alt: Build status
  :target: https://github.com/Julian/colortest/actions?query=workflow%3ACI

.. |Codecov| image:: https://codecov.io/gh/Julian/colortest/branch/master/graph/badge.svg
  :alt: Codecov Code coverage
  :target: https://codecov.io/gh/Julian/colortest

A simple script that checks for terminal true color support.
